@@ -9,9 +9,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 from . import auth
 from . import dbapi
@@ -20,4 +17,6 @@ from . import constants
 from . import exceptions
 from . import logging
 
-__version__ = "0.304.0"
+__all__ = ['auth', 'dbapi', 'client', 'constants', 'exceptions', 'logging']
+
+__version__ = "0.306.0"
