@@ -9,18 +9,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 import abc
 import os
 
-from six import with_metaclass
-from typing import Any, Optional, Text  # NOQA
+from typing import Optional
+from requests.auth import AuthBase
 
 
-class Authentication(with_metaclass(abc.ABCMeta)):  # type: ignore
+class Authentication(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def set_http_session(self, http_session):
         pass
@@ -43,17 +40,16 @@ class Authentication(with_metaclass(abc.ABCMeta)):  # type: ignore
 class KerberosAuthentication(Authentication):
     def __init__(
         self,
-        config=None,  # type: Optional[Text]
-        service_name=None,  # type: Text
-        mutual_authentication=False,  # type: bool
-        force_preemptive=False,  # type: bool
-        hostname_override=None,  # type: Optional[Text]
-        sanitize_mutual_error_response=True,  # type: bool
-        principal=None,  # type: Optional[Text]
-        delegate=False,  # type: bool
-        ca_bundle=None,  # type: Optional[Text]
-    ):
-        # type: (...) -> None
+        config: Optional[str] = None,
+        service_name: str = None,
+        mutual_authentication: bool = False,
+        force_preemptive: bool = False,
+        hostname_override: Optional[str] = None,
+        sanitize_mutual_error_response: bool = True,
+        principal: Optional[str] = None,
+        delegate: bool = False,
+        ca_bundle: Optional[str] = None,
+    ) -> None:
         self._config = config
         self._service_name = service_name
         self._mutual_authentication = mutual_authentication
@@ -131,3 +127,38 @@ class BasicAuthentication(Authentication):
 
     def handle_error(self, handle_error):
         pass
+
+
+class _BearerAuth(AuthBase):
+    """
+    Custom implementation of Authentication class for bearer token
+    """
+    def __init__(self, token):
+        self.token = token
+
+    def __call__(self, r):
+        r.headers["Authorization"] = "Bearer " + self.token
+        return r
+
+
+class JWTAuthentication(Authentication):
+
+    def __init__(self, token):
+        self.token = token
+
+    def set_client_session(self, client_session):
+        pass
+
+    def set_http_session(self, http_session):
+        http_session.auth = _BearerAuth(self.token)
+        return http_session
+
+    def setup(self, trino_client):
+        self.set_client_session(trino_client.client_session)
+        self.set_http_session(trino_client.http_session)
+
+    def get_exceptions(self):
+        return ()
+
+    def handle_error(self, handle_error):
+        pass
