@@ -11,51 +11,48 @@
 # limitations under the License.
 """
 
-This module implements the Presto protocol to submit SQL statements, track
+This module implements the Trino protocol to submit SQL statements, track
 their state and retrieve their result as described in
-https://github.com/prestosql/presto/wiki/HTTP-Protocol
-and Presto source code.
+https://github.com/trinodb/trino/wiki/HTTP-Protocol
+and Trino source code.
 
 The outline of a query is:
 - Send HTTP POST to the coordinator
 - Retrieve HTTP response with ``nextUri``
 - Get status of the query execution by sending a HTTP GET to the coordinator
 
-Presto queries are managed by the ``PrestoQuery`` class. HTTP requests are
-managed by the ``PrestoRequest`` class. the status of a query is represented
-by ``PrestoStatus`` and the result by ``PrestoResult``.
+Trino queries are managed by the ``TrinoQuery`` class. HTTP requests are
+managed by the ``TrinoRequest`` class. the status of a query is represented
+by ``TrinoStatus`` and the result by ``TrinoResult``.
 
 
-The main interface is :class:`PrestoQuery`: ::
+The main interface is :class:`TrinoQuery`: ::
 
-    >> request = PrestoRequest(host='coordinator', port=8080, user='test')
-    >> query =  PrestoQuery(request, sql)
+    >> request = TrinoRequest(host='coordinator', port=8080, user='test')
+    >> query =  TrinoQuery(request, sql)
     >> rows = list(query.execute())
 """
-from __future__ import absolute_import, division, print_function
 
 import copy
 import os
-from typing import Any, Dict, List, Optional, Text, Tuple, Union  # NOQA for mypy types
+from typing import Any, Dict, List, Optional, Tuple, Union
+
+import requests
 
 import trino.logging
-import requests
 from trino import constants, exceptions
 from trino.transaction import NO_TRANSACTION
 
-
-__all__ = ["PrestoQuery", "PrestoRequest"]
-
+__all__ = ["TrinoQuery", "TrinoRequest"]
 
 logger = trino.logging.get_logger(__name__)
 
-
 MAX_ATTEMPTS = constants.DEFAULT_MAX_ATTEMPTS
 SOCKS_PROXY = os.environ.get("SOCKS_PROXY")
 if SOCKS_PROXY:
     PROXIES = {"http": "socks5://" + SOCKS_PROXY, "https": "socks5://" + SOCKS_PROXY}
 else:
-    PROXIES = None
+    PROXIES = {}
 
 
 class ClientSession(object):
@@ -97,7 +94,7 @@ def get_session_property_values(headers, header):
     return [(k.strip(), v.strip()) for k, v in (kv.split("=", 1) for kv in kvs)]
 
 
-class PrestoStatus(object):
+class TrinoStatus(object):
     def __init__(self, id, stats, warnings, info_uri, next_uri, rows, columns=None):
         self.id = id
         self.stats = stats
@@ -109,7 +106,7 @@ class PrestoStatus(object):
 
     def __repr__(self):
         return (
-            "PrestoStatus("
+            "TrinoStatus("
             "id={}, stats={{...}}, warnings={}, info_uri={}, next_uri={}, rows=<count={}>"
             ")".format(
                 self.id,
@@ -121,9 +118,9 @@ class PrestoStatus(object):
         )
 
 
-class PrestoRequest(object):
+class TrinoRequest(object):
     """
-    Manage the HTTP requests of a Presto query.
+    Manage the HTTP requests of a Trino query.
 
     :param host: name of the coordinator
     :param port: TCP port to connect to the coordinator
@@ -131,7 +128,7 @@ class PrestoRequest(object):
                  and query scheduling.
     :param source: associated with the query. It is useful for access
                    control and query scheduling.
-    :param catalog: to query. The *catalog* is associated with a Presto
+    :param catalog: to query. The *catalog* is associated with a Trino
                     connector. This variable sets the default catalog used
                     by SQL statements. For example, if *catalog* is set
                     to ``some_catalog``, the SQL statement
@@ -144,7 +141,7 @@ class PrestoRequest(object):
                    ``some_schema``, the SQL statement
                    ``SELECT * FROM some_table`` will actually query the
                    table ``some_catalog.some_schema.some_table``.
-    :param session_properties: set specific Presto behavior for the current
+    :param session_properties: set specific Trino behavior for the current
                                session. Please refer to the output of
                                ``SHOW SESSION`` to check the available
                                properties.
@@ -165,8 +162,8 @@ class PrestoRequest(object):
     - An URI to get more information about the execution of the query
     - Statistics about the current query execution
 
-    Please refer to :class:`PrestoStatus` to access the status returned by
-    :meth:`PrestoRequest.process`.
+    Please refer to :class:`TrinoStatus` to access the status returned by
+    :meth:`TrinoRequest.process`.
 
     When the client makes an HTTP request, it may encounter the following
     errors:
@@ -187,31 +184,30 @@ class PrestoRequest(object):
     http = requests
 
     HTTP_EXCEPTIONS = (
-        http.ConnectionError,  # type: ignore
-        http.Timeout,  # type: ignore
+        http.ConnectionError,
+        http.Timeout,
     )
 
     def __init__(
         self,
-        host,  # type: Text
-        port,  # type: int
-        user,  # type: Text
-        source=None,  # type: Text
-        catalog=None,  # type: Text
-        schema=None,  # type: Text
-        session_properties=None,  # type: Optional[Dict[Text, Any]]
-        http_session=None,  # type: Any
-        http_headers=None,  # type: Optional[Dict[Text, Text]]
-        transaction_id=NO_TRANSACTION,  # type: Optional[Text]
-        http_scheme=constants.HTTP,  # type: Text
-        auth=constants.DEFAULT_AUTH,  # type: Optional[Any]
-        redirect_handler=None,
-        max_attempts=MAX_ATTEMPTS,  # type: int
-        request_timeout=constants.DEFAULT_REQUEST_TIMEOUT,  # type: Union[float, Tuple[float, float]]
+        host: str,
+        port: int,
+        user: str,
+        source: str = None,
+        catalog: str = None,
+        schema: str = None,
+        session_properties: Optional[Dict[str, Any]] = None,
+        http_session: Any = None,
+        http_headers: Optional[Dict[str, str]] = None,
+        transaction_id: Optional[str] = NO_TRANSACTION,
+        http_scheme: str = constants.HTTP,
+        auth: Optional[Any] = constants.DEFAULT_AUTH,
+        redirect_handler: Any = None,
+        max_attempts: int = MAX_ATTEMPTS,
+        request_timeout: Union[float, Tuple[float, float]] = constants.DEFAULT_REQUEST_TIMEOUT,
         handle_retry=exceptions.RetryWithExponentialBackoff(),
-        verify=True     # type: Any
-    ):
-        # type: (...) -> None
+        verify: bool = True
+    ) -> None:
         self._client_session = ClientSession(
             catalog,
             schema,
@@ -224,13 +220,12 @@ class PrestoRequest(object):
 
         self._host = host
         self._port = port
-        self._next_uri = None  # type: Optional[Text]
+        self._next_uri: Optional[str] = None
 
         if http_session is not None:
             self._http_session = http_session
         else:
-            # mypy cannot follow module import
-            self._http_session = self.http.Session()  # type: ignore
+            self._http_session = self.http.Session()
             self._http_session.verify = verify
         self._http_session.headers.update(self.http_headers)
         self._exceptions = self.HTTP_EXCEPTIONS
@@ -256,8 +251,7 @@ class PrestoRequest(object):
         self._client_session.transaction_id = value
 
     @property
-    def http_headers(self):
-        # type: () -> Dict[Text, Text]
+    def http_headers(self) -> Dict[str, str]:
         headers = {}
 
         headers[constants.HEADER_CATALOG] = self._client_session.catalog
@@ -283,13 +277,11 @@ class PrestoRequest(object):
         return headers
 
     @property
-    def max_attempts(self):
-        # type: () -> int
+    def max_attempts(self) -> int:
         return self._max_attempts
 
     @max_attempts.setter
-    def max_attempts(self, value):
-        # type: (int) -> None
+    def max_attempts(self, value) -> None:
         self._max_attempts = value
         if value == 1:  # No retry
             self._get = self._http_session.get
@@ -311,20 +303,17 @@ class PrestoRequest(object):
         self._post = with_retry(self._http_session.post)
         self._delete = with_retry(self._http_session.delete)
 
-    def get_url(self, path):
-        # type: (Text) -> Text
+    def get_url(self, path) -> str:
         return "{protocol}://{host}:{port}{path}".format(
             protocol=self._http_scheme, host=self._host, port=self._port, path=path
         )
 
     @property
-    def statement_url(self):
-        # type: () -> Text
+    def statement_url(self) -> str:
         return self.get_url(constants.URL_STATEMENT_PATH)
 
     @property
-    def next_uri(self):
-        # type: () -> Text
+    def next_uri(self) -> Optional[str]:
         return self._next_uri
 
     def post(self, sql, additional_http_headers=None):
@@ -373,11 +362,11 @@ class PrestoRequest(object):
     def _process_error(self, error, query_id):
         error_type = error["errorType"]
         if error_type == "EXTERNAL":
-            raise exceptions.PrestoExternalError(error, query_id)
+            raise exceptions.TrinoExternalError(error, query_id)
         elif error_type == "USER_ERROR":
-            return exceptions.PrestoUserError(error, query_id)
+            return exceptions.TrinoUserError(error, query_id)
 
-        return exceptions.PrestoQueryError(error, query_id)
+        return exceptions.TrinoQueryError(error, query_id)
 
     def raise_response_error(self, http_response):
         if http_response.status_code == 503:
@@ -390,8 +379,7 @@ class PrestoRequest(object):
             )
         )
 
-    def process(self, http_response):
-        # type: (requests.Response) -> PrestoStatus
+    def process(self, http_response) -> TrinoStatus:
         if not http_response.ok:
             self.raise_response_error(http_response)
 
@@ -415,7 +403,7 @@ class PrestoRequest(object):
 
         self._next_uri = response.get("nextUri")
 
-        return PrestoStatus(
+        return TrinoStatus(
             id=response["id"],
             stats=response["stats"],
             warnings=response.get("warnings", []),
@@ -426,9 +414,9 @@ class PrestoRequest(object):
         )
 
 
-class PrestoResult(object):
+class TrinoResult(object):
     """
-    Represent the result of a Presto query as an iterator on rows.
+    Represent the result of a Trino query as an iterator on rows.
 
     This class implements the iterator protocol as a generator type
     https://docs.python.org/3/library/stdtypes.html#generator-types
@@ -440,8 +428,7 @@ class PrestoResult(object):
         self._rownumber = 0
 
     @property
-    def rownumber(self):
-        # type: () -> int
+    def rownumber(self) -> int:
         return self._rownumber
 
     def __iter__(self):
@@ -452,7 +439,7 @@ class PrestoResult(object):
         self._rows = None
 
         # Subsequent fetches from GET requests until next_uri is empty.
-        while not self._query.is_finished():
+        while not self._query.finished:
             rows = self._query.fetch()
             for row in rows:
                 self._rownumber += 1
@@ -464,30 +451,33 @@ class PrestoResult(object):
         return self._query.response_headers
 
 
-class PrestoQuery(object):
-    """Represent the execution of a SQL statement by Presto."""
+class TrinoQuery(object):
+    """Represent the execution of a SQL statement by Trino."""
 
     def __init__(
         self,
-        request,  # type: PrestoRequest
-        sql,  # type: Text
-    ):
-        # type: (...) -> None
-        self.query_id = None  # type: Optional[Text]
-
-        self._stats = {}  # type: Dict[Any, Any]
-        self._warnings = []  # type: List[Dict[Any, Any]]
-        self._columns = None  # type: Optional[List[Text]]
+        request: TrinoRequest,
+        sql: str,
+    ) -> None:
+        self.query_id: Optional[str] = None
 
+        self._stats: Dict[Any, Any] = {}
+        self._warnings: List[Dict[Any, Any]] = []
+        self._columns: Optional[List[str]] = None
         self._finished = False
         self._cancelled = False
         self._request = request
         self._sql = sql
-        self._result = PrestoResult(self)
+        self._result = TrinoResult(self)
         self._response_headers = None
 
     @property
     def columns(self):
+        if self.query_id:
+            while not self._columns and not self.finished and not self.cancelled:
+                # Columns don't return immediate after query is summited.
+                # Continue fetching data until columns are available and push fetched rows into buffer.
+                self._result._rows += self.fetch()
         return self._columns
 
     @property
@@ -502,31 +492,29 @@ class PrestoQuery(object):
     def result(self):
         return self._result
 
-    def execute(self, additional_http_headers=None):
-        # type: () -> PrestoResult
-        """Initiate a Presto query by sending the SQL statement
+    def execute(self, additional_http_headers=None) -> TrinoResult:
+        """Initiate a Trino query by sending the SQL statement
 
         This is the first HTTP request sent to the coordinator.
         It sets the query_id and returns a Result object used to
         track the rows returned by the query. To fetch all rows,
-        call fetch() until is_finished is true.
+        call fetch() until finished is true.
         """
-        if self._cancelled:
-            raise exceptions.PrestoUserError("Query has been cancelled", self.query_id)
+        if self.cancelled:
+            raise exceptions.TrinoUserError("Query has been cancelled", self.query_id)
 
         response = self._request.post(self._sql, additional_http_headers)
         status = self._request.process(response)
         self.query_id = status.id
-        self._stats.update({u"queryId": self.query_id})
+        self._stats.update({"queryId": self.query_id})
         self._stats.update(status.stats)
         self._warnings = getattr(status, "warnings", [])
         if status.next_uri is None:
             self._finished = True
-        self._result = PrestoResult(self, status.rows)
+        self._result = TrinoResult(self, status.rows)
         return self._result
 
-    def fetch(self):
-        # type: () -> List[List[Any]]
+    def fetch(self) -> List[List[Any]]:
         """Continue fetching data for the current query_id"""
         response = self._request.get(self._request.next_uri)
         status = self._request.process(response)
@@ -539,26 +527,35 @@ class PrestoQuery(object):
             self._finished = True
         return status.rows
 
-    def cancel(self):
-        # type: () -> None
+    def cancel(self) -> None:
         """Cancel the current query"""
-        if self.query_id is None or self.is_finished():
+        if self.query_id is None or self.finished:
             return
 
-        self._cancelled = True
         url = self._request.get_url("/v1/query/{}".format(self.query_id))
         logger.debug("cancelling query: %s", self.query_id)
         response = self._request.delete(url)
         logger.info(response)
         if response.status_code == requests.codes.no_content:
+            self._cancelled = True
             logger.debug("query cancelled: %s", self.query_id)
             return
+
         self._request.raise_response_error(response)
 
-    def is_finished(self):
-        # type: () -> bool
+    def is_finished(self) -> bool:
+        import warnings
+        warnings.warn("is_finished is deprecated, use finished instead", DeprecationWarning)
+        return self.finished
+
+    @property
+    def finished(self) -> bool:
         return self._finished
 
+    @property
+    def cancelled(self) -> bool:
+        return self._cancelled
+
     @property
     def response_headers(self):
         return self._response_headers
